@@ -33,9 +33,6 @@ test_that("Input errors are thrown correctly",{
   expect_error(ds(egdata,4,key="hn",adjustment="bananas"),
                suppressMessages(message("'arg' should be one of \"cos\", \"herm\", \"poly\"")))
 
-  # first cutpoint not zero when no left truncation
-  expect_error(ds(egdata,4,cutpoints=c(2,3,4)),
-               "The first cutpoint must be 0 or the left truncation distance!")
 
   # uniform without adjustments
   expect_error(ds(egdata,4,key="unif", adjustment=NULL),
@@ -60,6 +57,25 @@ test_that("Input errors are thrown correctly",{
 })
 
 
+test_that("binning works", {
+  # first cutpoint not zero when no left truncation
+  expect_error(ds(egdata,4,cutpoints=c(2,3,4)),
+               "The first cutpoint must be 0 or the left truncation distance!")
+
+  tst_distances <- data.frame(distance = c(0, 0, 0, 10, 50, 70, 110))
+  expect_equal(as.vector(table(create_bins(tst_distances,
+                                           c(0, 10, 65, 200))$distbegin)),
+               c(4, 1, 2))
+
+  # per bug #108
+  data("wren_snapshot")
+
+  binned <- expect_warning(create_bins(wren_snapshot,
+                                       c(0, 10, 20, 30, 40, 60, 80, 100)),
+                           "Some distances were outside bins and have been removed.")
+  expect_equal(as.vector(table(binned$distbegin)), c(3, 9, 19, 46, 28, 11))
+})
+
 test_that("Simple models work",{
   skip_on_cran()
 
@@ -81,8 +97,8 @@ test_that("Simple models work",{
   egdata <- egdata[egdata$observer==1,]
 
   # half-normal key should get selected
-  ds.dht.model <- suppressMessages(ds(egdata,4,region.table=region,
-                                      sample.table=samples,obs.table=obs))
+  ds.dht.model <- suppressMessages(ds(egdata,4,region_table=region,
+                                      sample_table=samples,obs_table=obs))
   # pars and lnl
   expect_equal(ds.dht.model$ddf$par, 0.6632435,tol=par.tol)
   expect_equal(ds.dht.model$ddf$lnl, -154.5692, tol=lnl.tol)
@@ -90,8 +106,8 @@ test_that("Simple models work",{
 
   # specify order 2 cosine adjustments
   ds.model.cos2<-suppressMessages(ds(egdata,4,adjustment="cos",order=2,
-                                     region.table=region, sample.table=samples,
-                                     obs.table=obs,monotonicity=FALSE))
+                                     region_table=region, sample_table=samples,
+                                     obs_table=obs,monotonicity=FALSE))
   # pars and lnl
   #result <- ddf(dsmodel=~mcds(key="hn", formula=~1, adj.series="cos",
   #                            adj.order=2), data=egdata, method="ds",
@@ -104,7 +120,7 @@ test_that("Simple models work",{
   # specify order 2 and 4 cosine adjustments
   ds.model.cos24<-suppressMessages(suppressWarnings(ds(egdata,4,
                      adjustment="cos",order=c(2,4),
-                     region.table=region, sample.table=samples, obs.table=obs,
+                     region_table=region, sample_table=samples, obs_table=obs,
                      monotonicity=FALSE)))
   tp <- c(0.661391356, -0.008769883, -0.041465153)
   expect_equal(unname(ds.model.cos24$ddf$par), tp, tol=par.tol)
@@ -113,8 +129,8 @@ test_that("Simple models work",{
 
   # hazard rate
   ds.model.hr<-suppressMessages(ds(egdata,4,key="hr",
-                  adjustment=NULL, region.table=region,
-                  sample.table=samples, obs.table=obs))
+                  adjustment=NULL, region_table=region,
+                  sample_table=samples, obs_table=obs))
   #result <- ddf(dsmodel=~mcds(key="hr", formula=~1), data=egdata, method="ds",
   #              meta.data=list(width=4))
   tp <- c(0.9375891, 0.7245641)
@@ -164,39 +180,12 @@ test_that("Truncation is handled",{
                              cutpoints=c(0,1,2,3,3.8)))$ddf$meta.data$width,3.8)
 
   # largest bin
-  bin.data <- create.bins(egdata,c(0,1,2,3,3.8))
+  bin.data <- create_bins(egdata,c(0,1,2,3,3.8))
   expect_equal(suppressMessages(ds(bin.data, key="hn",
                                    order=0))$ddf$meta.data$width, 3.8)
 
 })
 
-test_that("adjustments expand correctly",{
-  skip_on_cran()
-
-  egdata <- egdata[egdata$observer==1,]
-
-  # hn + cos(2)
-  expect_equal(suppressWarnings(summary(ds(egdata, 4, key="hn",
-                                           order=2))$ddf$name.message),
-               "half-normal key function with cosine(2) adjustments")
-
-  # hn + cos(2,3)
-  expect_equal(suppressWarnings(summary(ds(egdata, 4, key="hn",
-                                           order=2:3))$ddf$name.message),
-               "half-normal key function with cosine(2,3) adjustments")
-
-  # hn + cos(2,3,4,5)
-  expect_equal(suppressWarnings(summary(ds(egdata, 4, key="hn",
-                                           order=5))$ddf$name.message),
-               "half-normal key function with cosine(2,3,4,5) adjustments")
-
-  #unif + cos(1,2)
-  expect_equal(suppressWarnings(summary(ds(egdata, 4, key="unif",
-                                           order=2))$ddf$name.message),
-               "uniform key function with cosine(1,2) adjustments")
-
-})
-
 # reported by Len Thomas 20 August
 test_that("Percentage truncation works when distances are missing",{
   skip_on_cran()
@@ -209,58 +198,16 @@ test_that("Percentage truncation works when distances are missing",{
 
 
 # just distend and distbegin can be supplied
-
 test_that("just distend and distbegin can be supplied", {
   # make some data
-  bin.data <- create.bins(egdata, c(0, 1, 2, 3, 4))
+  bin.data <- create_bins(egdata, c(0, 1, 2, 3, 4))
   bin.data$distance <- NULL
   expect_message(ds.model <- ds(bin.data, 4, monotonicity=FALSE, key="hn",
                                 adjustment=NULL),
                  "^Columns \"distbegin\" and \"distend\" in data: performing a binned analysis....*")
 })
 
-# max adjustments arg
-test_that("max.adjustments works",{
-  skip_on_cran()
-
-  egdata <- egdata[egdata$observer==1,]
-
-  # setting max.adjustments=0 gives no adjustments
-  expect_equal(summary(ds(egdata, 4, key="hn", max.adjustments=0,
-                          adjustment="cos"))$ddf$name.message,
-               "half-normal key function")
-
-  # some delicious stake
-  data(stake77)
-  dists <- stake77$PD[stake77$Obs2==1]
-  dists <- c(dists, dists[dists>10])
-  dists <- c(dists, dists[dists<5])
-  dists <- c(dists, dists[dists<5])
-
-  # ignore warnings below from monotonicity checks, don't care about that here
-  expect_equal(summary(suppressWarnings(
-                ds(dists, 20, key="hn", max.adjustments=3,
-                   adjustment="cos")))$ddf$name.message,
-               "half-normal key function with cosine(2,3,4) adjustments")
-
-  expect_equal(summary(suppressWarnings(
-                ds(dists, 20, key="hn", max.adjustments=2,
-                   adjustment="cos")))$ddf$name.message,
-               "half-normal key function with cosine(2,3) adjustments")
-
-  expect_equal(summary(suppressWarnings(
-                ds(dists, 20, key="hn", max.adjustments=1,
-                   adjustment="cos")))$ddf$name.message,
-               "half-normal key function with cosine(2) adjustments")
-
-  expect_equal(summary(suppressWarnings(
-                ds(dists, 20, key="hn", max.adjustments=6,
-                   adjustment="cos")))$ddf$name.message,
-               "half-normal key function with cosine(2,3,4) adjustments")
-})
-
 # warnings when bad models get fitted
-
 test_that("warnings of bad models get thrown",{
   skip_on_cran()
 
